import logging

import fedmsg.consumers

from . import ci_processor
from . import exceptions as exc


_log = logging.getLogger(__name__)


class PipelineConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = [
        'org.centos.prod.ci.pipeline.complete',
        'org.centos.prod.ci.pipeline.compose.complete',
        'org.centos.prod.ci.pipeline.compose.test.integration.complete',
        'org.centos.prod.ci.pipeline.image.complete',
        'org.centos.prod.ci.pipeline.image.test.smoke.complete',
        'org.centos.prod.ci.pipeline.package.complete',
        'org.centos.prod.ci.pipeline.package.ignore',
        'org.centos.prod.ci.pipeline.allpackages-build.complete',
        'org.centos.prod.ci.pipeline.allpackages-build.image.complete',
        'org.centos.prod.ci.pipeline.allpackages-build.package.test.functional.complete',
        'org.centos.prod.ci.pipeline.allpackages-build.package.complete',
        'org.centos.prod.ci.pipeline.allpackages-build.package.ignored',
    ]

    config_key = 'resultsdb_listener.enabled'

    def __init__(self, *args, **kw):
        super(PipelineConsumer, self).__init__(*args, **kw)
        self.processor = ci_processor.CIProcessor(self.log)

    def consume(self, message):
        msg = message['body']

        _log.info(
            "PipelineConsumer: Got a message %r: %r",
            msg['msg']['topic'], msg['msg_id'])

        try:
            data = self.processor.process(msg)
            self.processor.send(data)
        except exc.ListenerMsgError, e:
            self.log.debug(e)

        _log.info("PipelineConsumer: Done")
